@@ -48,10 +48,10 @@ public:
      */
     void save();
 
-signals:
+Q_SIGNALS:
     void changed(bool);
 
-private slots:
+private Q_SLOTS:
     void addDictionary();
     void deleteDictionary();
     void moveUp();
@@ -72,10 +72,6 @@ private slots:
     }
 
 private:
-    /**
-     * Object holding all the configuration
-     */
-    KConfig *config;
     QStringList newDictionaryFiles;
     QStringList removedDictionaryFiles;
     QStandardItemModel *model;
